@@ -1,10 +1,11 @@
+# coding=utf-8
 from django.core.files.storage import get_storage_class
 from django_helpers import get_settings_val, check_settings_val_exist
 
 __author__ = 'ajumell'
 
 from django.db import models
-from django_helpers.forms.fields import ThumbnailImageField
+from django_helpers.apps.forms.fields import ThumbnailImageField
 
 check_settings_val_exist('MEDIA_ROOT')
 check_settings_val_exist('MEDIA_URL')
@@ -17,6 +18,7 @@ class Image(models.Model):
     alternate_text = models.CharField(max_length=255, blank=True)
     tooltip = models.CharField(max_length=255, blank=True)
     image = ThumbnailImageField(upload_to=UPLOAD_TO, storage=STORAGE())
+    folder = models.CharField(max_length=255, blank=True)
 
     def __unicode__(self):
         return self.name
@@ -27,7 +29,7 @@ class Image(models.Model):
 
     @property
     def thumbnail(self):
-        return self.image.thumbnail
+        return getattr(self.image,'thumbnail')
 
 
 class ImageGroup(models.Model):
