@@ -1,18 +1,16 @@
 # coding=utf-8
 from django.contrib import messages
 from django_helpers.apps.image_manager.forms import AddImageFormRenderer, AddImageForm, Image
-from django_helpers.templatetags.static_manger import add_css_file, add_js_file, require_jquery, require_jquery_ui
 from django_helpers.helpers.views import render_to_response, redirect
 
 __author__ = 'ajumell'
 
-require_jquery()
-require_jquery_ui()
-add_css_file('css/image-manager/main.css')
-
-add_js_file('fancybox/jquery.fancybox.pack.js')
-add_css_file('fancybox/jquery.fancybox.css')
-
+# require_jquery()
+# require_jquery_ui()
+# add_css_file('css/image-manager/main.css')
+#
+# add_js_file('fancybox/jquery.fancybox.pack.js')
+# add_css_file('fancybox/jquery.fancybox.css')
 
 
 def generate_token(param):
@@ -53,7 +51,7 @@ def delete_image(request, image_id, image_slug):
             return redirect(index)
         else:
             pass
-    return render_to_response('image-manager/delete-confirm.html',request, {
+    return render_to_response('image-manager/delete-confirm.html', request, {
         'token': token,
         'image': image
     })
